!include "MUI.nsh"

; The name of the installer
Name "SportTool"

SetCompressor "lzma"

; The file to write
OutFile "..\distr\@fullName@-setup.exe"

; The default installation directory
InstallDir $PROGRAMFILES\SportTool

; Registry key to check for directory (so if you install again, it will 
; overwrite the old one automatically)
InstallDirRegKey HKLM "Software\Babichev\SportTool\@version@" ""

XPStyle on
LicenseData "..\src\com\fn\BikersLog\license\copying"

;--------------------------------

!define MUI_HEADERIMAGE
!define MUI_ABORTWARNING

;--------------------------------

; Pages

!insertmacro MUI_PAGE_LICENSE "..\src\com\fn\BikersLog\license\copying"
!insertmacro MUI_PAGE_DIRECTORY
!insertmacro MUI_PAGE_INSTFILES

!insertmacro MUI_UNPAGE_CONFIRM
!insertmacro MUI_UNPAGE_INSTFILES

;--------------------------------

!insertmacro MUI_LANGUAGE "English"

;--------------------------------

; The stuff to install
Section "SportTool (required)"

  SectionIn RO
  
  ; Set output path to the installation directory.
  SetOutPath $INSTDIR
  
  ; Put file there
  File "..\distr\@fullName@.jar"
  File "..\scripts\jlaunch.exe"
  File "..\setup\bikerslog.ico"
  
  ; Write the installation path into the registry
  WriteRegStr HKLM "SOFTWARE\babichev\SportTool\@version@" "path" "$INSTDIR"
  
  ; Write the uninstall keys for Windows
  WriteRegStr HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\SportTool" "DisplayName" "SportTool @version@"
  WriteRegStr HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\SportTool" "UninstallString" '"$INSTDIR\uninstall.exe"'
  WriteRegDWORD HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\SportTool" "NoModify" 1
  WriteRegDWORD HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\SportTool" "NoRepair" 1
  WriteUninstaller "uninstall.exe"
  
  CreateDirectory "$SMPROGRAMS\SportTool"
  CreateShortCut "$SMPROGRAMS\SportTool\SportTool.lnk" "$INSTDIR\jlaunch.exe" "-jar $\"$INSTDIR\@fullName@.jar$\"" "$INSTDIR\bikerslog.ico"
  CreateShortCut "$INSTDIR\SportTool.lnk" "$INSTDIR\jlaunch.exe" "-jar $\"$INSTDIR\@fullName@.jar$\"" "$INSTDIR\bikerslog.ico"
  CreateShortCut "$DESKTOP\SportTool.lnk" "$INSTDIR\jlaunch.exe" "-jar $\"$INSTDIR\@fullName@.jar$\"" "$INSTDIR\bikerslog.ico"
  CreateShortCut "$QUICKLAUNCH\SportTool.lnk" "$INSTDIR\jlaunch.exe" "-jar $\"$INSTDIR\@fullName@.jar$\"" "$INSTDIR\bikerslog.ico"
  CreateShortCut "$SMPROGRAMS\SportTool\SportTool Homepage.lnk" "http://www.babichev.info"
  CreateShortCut "$SMPROGRAMS\SportTool\Uninstall.lnk" "$INSTDIR\uninstall.exe" "" "$INSTDIR\uninstall.exe" 0
  
  ; create file association
  ; back up old value of .spt
!define Index "Line${__LINE__}"
  ReadRegStr $1 HKCR ".spt" ""
  StrCmp $1 "" "${Index}-NoBackup"
    StrCmp $1 "SportToolFile" "${Index}-NoBackup"
    WriteRegStr HKCR ".spt" "backup_val" $1
"${Index}-NoBackup:"
  WriteRegStr HKCR ".spt" "" "SportToolFile"
  ReadRegStr $0 HKCR "SportToolFile" ""
  StrCmp $0 "" 0 "${Index}-Skip"
	WriteRegStr HKCR "SportToolFile" "" "SportTool File"
	WriteRegStr HKCR "SportToolFile\shell" "" "open"
	WriteRegStr HKCR "SportToolFile\DefaultIcon" "" "$INSTDIR\bikerslog.ico"
"${Index}-Skip:"
  WriteRegStr HKCR "SportToolFile\shell\open\command" "" \
    '"$INSTDIR\jlaunch.exe" -jar $\"$INSTDIR\@fullName@.jar$\" "%1"'
  WriteRegStr HKCR "SportToolFile\shell\edit" "" "Edit SportTool File"
  WriteRegStr HKCR "SportToolFile\shell\edit\command" "" \
    '"$INSTDIR\jlaunch.exe" -jar $\"$INSTDIR\@fullName@.jar$\" "%1"'
!undef Index
SectionEnd

;--------------------------------

; Uninstaller

Section "Uninstall"
  
  ; remove file association
!define Index "Line${__LINE__}"
  ReadRegStr $1 HKCR ".spt" ""
  StrCmp $1 "SportToolFile" 0 "${Index}-NoOwn" ; only do this if we own it
    ReadRegStr $1 HKCR ".spt" "backup_val"
    StrCmp $1 "" 0 "${Index}-Restore" ; if backup="" then delete the whole key
      DeleteRegKey HKCR ".spt"
    Goto "${Index}-NoOwn"
"${Index}-Restore:"
      WriteRegStr HKCR ".spt" "" $1
      DeleteRegValue HKCR ".spt" "backup_val"
   
    DeleteRegKey HKCR "SportToolFile" ;Delete key with association settings

"${Index}-NoOwn:"
!undef Index

  ; Remove registry keys
  DeleteRegKey HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\SportTool"
  DeleteRegKey HKLM "SOFTWARE\babichev\SportTool\@version@"

  ; Remove files and uninstaller
  Delete $INSTDIR\SportTool.lnk
  Delete $DESKTOP\SportTool.lnk
  Delete $QUICKLAUNCH\SportTool.lnk
  Delete $INSTDIR\jlaunch.exe
  Delete $INSTDIR\@fullName@.jar
  Delete $INSTDIR\bikerslog.ico
  Delete $INSTDIR\uninstall.exe

  ; Remove shortcuts, if any
  Delete "$SMPROGRAMS\SportTool\*.*"

  ; Remove directories used
  RMDir "$SMPROGRAMS\SportTool"
  RMDir "$INSTDIR"

SectionEnd

