/*
 * Config.java
 *
 * Created on 27  2002 ., 11:42
 */

package com.fn.BikersLog;


import java.awt.Font;
import java.awt.Rectangle;
import java.io.File;
import java.io.IOException;
import java.util.LinkedList;
import java.util.List;
import java.util.ListIterator;
import java.util.Set;
import java.util.TreeSet;


/**
 *
 * @author  asso
 */
public class Config {

    private static Rectangle position;
    private static List lastLogs;
    private static int rememberLogs;
    private static boolean autoOpenLast;
    private static boolean showSplash;
    private static String units;
    private static String lookAndFeel;
    private static Set gridColumns;
    private static boolean disableNotify;
    private static TableOptionsListener tableOptionsListener;
    private static boolean tableEvent;
    private static boolean tableShowStartTime;
    private static boolean tableShowFinishDate;
    private static boolean tableShowScroll;
    private static CalendarOptionsListener calendarOptionsListener;
    private static boolean calendarEvent;
    private static Font calTitleFont;
    private static Font calDataFont;
    private static int[] calColumns;
    private static int[] tableColIndexes;
    private static int[] tableColWidths;
    private static boolean createBackup;
    
    static {
        disableNotify = false;
        tableEvent = false;
        calendarEvent = false;
        
        position = new Rectangle(20, 20, 600, 450);
        rememberLogs = 5;
        lastLogs = new LinkedList();
        autoOpenLast = false;
        showSplash = true;
        units = "metric";
        lookAndFeel = "Default";
        gridColumns = getDefaultGridColumns();
        tableShowStartTime = false;
        tableShowFinishDate = false;
        tableShowScroll = false;
        calTitleFont = new Font("SansSerif", Font.BOLD, 12);
        calDataFont = new Font("SansSerif", Font.PLAIN, 10);
        calColumns = getDefaultCalColumns();
        tableColIndexes = null;
        tableColWidths = null;
        createBackup = true;
        
        read();
    }
        
    private static void read() {
        position = OptionsDepot.getRectangle("position", position);
        rememberLogs = OptionsDepot.getInteger("rememberLogs", rememberLogs);
        lastLogs = OptionsDepot.getStringsList("lastLogs", lastLogs);
        autoOpenLast = OptionsDepot.getBoolean("autoOpenLast", autoOpenLast);
        showSplash = OptionsDepot.getBoolean("showSplash", showSplash);
        String distanceUnits = OptionsDepot.getString("distance",  "");
        if (distanceUnits.length() > 0) {
            if (distanceUnits.equals("kilometres"))
                units = "metric";
            else
                units = "imperial";
        }
        units = OptionsDepot.getString("units",  units);
        lookAndFeel = OptionsDepot.getString("laf", lookAndFeel);
        gridColumns = OptionsDepot.getIntegerSet("gridColumns", gridColumns);
        tableShowStartTime = OptionsDepot.getBoolean("tableShowStartTime", tableShowStartTime);
        tableShowFinishDate = OptionsDepot.getBoolean("tableShowFinishDate", tableShowFinishDate);
        tableShowScroll = OptionsDepot.getBoolean("tableShowScroll", tableShowScroll);
        calTitleFont = OptionsDepot.getFont("calTitleFont", calTitleFont);
        calDataFont = OptionsDepot.getFont("calDataFont", calDataFont);
        calColumns = OptionsDepot.getIntegerArr("calColumns", calColumns);
        tableColIndexes = OptionsDepot.getIntegerArr("tableColIndexes", tableColIndexes);
        tableColWidths = OptionsDepot.getIntegerArr("tableColWidths", tableColWidths);
        createBackup = OptionsDepot.getBoolean("backup", createBackup);
    }
    
    public static void save() throws IOException {
        OptionsDepot.setRectangle("position", position);
        OptionsDepot.setInteger("rememberLogs", rememberLogs);
        OptionsDepot.setStringsList("lastLogs", lastLogs);
        OptionsDepot.setBoolean("autoOpenLast", autoOpenLast);
        OptionsDepot.setBoolean("showSplash", showSplash);
        OptionsDepot.setString("units", units);
        OptionsDepot.setString("laf", lookAndFeel);
        OptionsDepot.setIntegerSet("gridColumns", gridColumns);
        OptionsDepot.setBoolean("tableShowStartTime", tableShowStartTime);
        OptionsDepot.setBoolean("tableShowFinishDate", tableShowFinishDate);
        OptionsDepot.setBoolean("tableShowScroll", tableShowScroll);
        OptionsDepot.setFont("calTitleFont", calTitleFont);
        OptionsDepot.setFont("calDataFont", calDataFont);
        OptionsDepot.setIntegerArr("calColumns", calColumns);
        OptionsDepot.setIntegerArr("tableColIndexes", tableColIndexes);
        OptionsDepot.setIntegerArr("tableColWidths", tableColWidths);
        OptionsDepot.setBoolean("backup", createBackup);
        OptionsDepot.save();
    }
    
    public static Rectangle getPosition() {
        return position;
    }
    
    public static void setPosition(Rectangle position) {
        Config.position = position;
    }

    public static void addToLastLogs(File file) {
        if (rememberLogs <= 0) return;
        
        String path = file.getAbsolutePath();
        for (ListIterator i = lastLogs.listIterator(); i.hasNext(); ) {
            String s = (String)i.next();
            if (path.equals(s))
                i.remove();
        }
        
        while (rememberLogs <= lastLogs.size())
            lastLogs.remove(0);
        
        lastLogs.add(path);
    }
    
    public static String getLastLog() {
        if (lastLogs.size() < 1)
            return null;
        return (String)lastLogs.get(lastLogs.size() - 1);
    }
    
    public static List getLastLogs() {
        return lastLogs;
    }
 
    public static boolean getAutoOpenLast() {
        return autoOpenLast;
    }
    
    public static void setAutoOpenLast(boolean v) {
        autoOpenLast = v;
    }
 
    public static boolean getShowSplash() {
        return showSplash;
    }
    
    public static void setShowSplash(boolean v) {
        showSplash = v;
    }
    
    public static String getUnits() {
        return units;
    }
    
    public static void setUnits(String v) {
        units = v;
        Units.setMetrics(units);
    }
    
    public static String getLookAndFeel() {
        return lookAndFeel;
    }    
    
    public static void setLookAndFeel(String v) {
        lookAndFeel = v;
    }    

    public static void disableNotifiers() {
        disableNotify = true;
        tableEvent = false;
    }

    public static void enableNotifiers() {
        disableNotify = false;
        if (tableEvent) {
            if (null != tableOptionsListener)
                tableOptionsListener.onOptionsChanged();
            tableEvent = false;
        }
        if (calendarEvent) {
            if (null != calendarOptionsListener)
                calendarOptionsListener.onOptionsChanged();
            calendarEvent = false;
        }
    }
    
    public static Set getDefaultGridColumns() {
        Set columns = new TreeSet();
        columns.add(new Integer(Event.COLUMN_TYPE));
        columns.add(new Integer(Event.COLUMN_START));
        columns.add(new Integer(Event.COLUMN_ELAPSED));
        columns.add(new Integer(Event.COLUMN_DISTANCE));
        columns.add(new Integer(Event.COLUMN_AVG_SPEED));
        columns.add(new Integer(Event.COLUMN_HEART_RATE));
        return columns;
    }
    
    public static Set getGridColumns() {
        return gridColumns;
    }
    
    public interface TableOptionsListener {
        public void onOptionsChanged();
    }
    
    public static void setTableOptionsListener(TableOptionsListener listener) {
        tableOptionsListener = listener;
    }
    
    public static boolean getTableShowStartTime() {
        return tableShowStartTime;
    }
    
    public static void setTableShowStartTime(boolean v) {
        if (v != tableShowStartTime) {
            tableShowStartTime = v;
            if (disableNotify)
                tableEvent = true;
            else
                if (null != tableOptionsListener)
                    tableOptionsListener.onOptionsChanged();
        }
    }
    
    public static boolean getTableShowFinishDate() {
        return tableShowFinishDate;
    }
    
    public static void setTableShowFinishDate(boolean v) {
        if (v != tableShowFinishDate) {
            tableShowFinishDate = v;
            if (disableNotify)
                tableEvent = true;
            else
                if (null != tableOptionsListener)
                    tableOptionsListener.onOptionsChanged();
        }
    }
    
    public static boolean getTableShowScroll() {
        return tableShowScroll;
    }
    
    public static void setTableShowScroll(boolean v) {
        if (v != tableShowScroll) {
            tableShowScroll = v;
            if (disableNotify)
                tableEvent = true;
            else
                if (null != tableOptionsListener)
                    tableOptionsListener.onOptionsChanged();
        }
    }
    
    public interface CalendarOptionsListener {
        public void onOptionsChanged();
    }
    
    public static void setCalendarOptionsListener(CalendarOptionsListener listener) {
        calendarOptionsListener = listener;
    }
    
    public static Font getCalendarTitleFont() {
        return calTitleFont;
    }
    
    public static void setCalendarTitleFont(Font v) {
        if (v != calTitleFont) {
            calTitleFont = v;
            if (disableNotify)
                calendarEvent = true;
            else
                if (null != calendarOptionsListener)
                    calendarOptionsListener.onOptionsChanged();
        }
    }
    
    public static Font getCalendarDataFont() {
        return calDataFont;
    }
    
    public static void setCalendarDataFont(Font v) {
        if (v != calDataFont) {
            calDataFont = v;
            if (disableNotify)
                calendarEvent = true;
            else
                if (null != calendarOptionsListener)
                    calendarOptionsListener.onOptionsChanged();
        }
    }
    
    public static int[] getCalendarColumns() {
        return calColumns;
    }
    
    public static void setCalendarColumns(int[] v) {
        if (v != calColumns) {
            calColumns = v;
            if (disableNotify)
                calendarEvent = true;
            else
                if (null != calendarOptionsListener)
                    calendarOptionsListener.onOptionsChanged();
        }
    }
    
    public static int[] getTableColIndexes() {
        return tableColIndexes;
    }
    
    public static void setTableColIndexes(int[] v) {
        tableColIndexes = v;
    }
    
    public static int[] getTableColWidths() {
        return tableColWidths;
    }
    
    public static void setTableColWidths(int[] v) {
        tableColWidths = v;
    }
    
    private static int[] getDefaultCalColumns() {
        int[] a = new int[4];
        a[0] = Event.COLUMN_TYPE;
        a[1] = Event.COLUMN_DISTANCE;
        a[2] = Event.COLUMN_AVG_SPEED;
        a[3] = Event.COLUMN_HEART_RATE;
        return a;
    }
    
    public static boolean getCreateBackup() {
        return createBackup;
    }
    
    public static void setCreateBackup(boolean v) {
        createBackup = v;
    }
}
