/*
 * EventsTableModel.java
 *
 * Created on 6  2004 ., 10:41
 */

package com.fn.BikersLog;


import java.text.DateFormat;
import java.util.Iterator;
import java.util.Set;
import javax.swing.event.ListDataListener;
import javax.swing.table.AbstractTableModel;


/**
 *
 * @author  asso
 */
public class EventsTableModel extends AbstractTableModel implements ListDataListener {
    
    private int[] mapping;
    private EventsList eventsList;
    private DateFormat startFormat;
    private DateFormat finishFormat;
    
    /** Creates a new instance of EventsTableModel */
    public EventsTableModel(EventsList eventsList) {
        this.eventsList = eventsList;
        updateColumns();
        updateDateFormat();
    }
    
    public void updateDateFormat() {
        if (Config.getTableShowStartTime())
            startFormat = DateFormat.getDateTimeInstance(DateFormat.SHORT, DateFormat.SHORT);
        else
            startFormat = DateFormat.getDateInstance(DateFormat.SHORT);
        if (Config.getTableShowFinishDate())
            finishFormat = DateFormat.getDateTimeInstance(DateFormat.SHORT, DateFormat.SHORT);
        else
            finishFormat = DateFormat.getTimeInstance(DateFormat.SHORT);
    }
    
    public int getColumnCount() {
        return mapping.length;
    }
    
    public int getRowCount() {
        return eventsList.getSize();
    }
    
    public Object getValueAt(int rowIndex, int columnIndex) {
        Event event = eventsList.get(rowIndex);
        int fieldIdx = mapping[columnIndex];
        Object obj = event.getColumnData(fieldIdx);
        if (null != obj) {
            if (Event.COLUMN_START == fieldIdx)
                obj = startFormat.format((java.util.Date)obj);
            else if (Event.COLUMN_FINISH == fieldIdx)
                obj = finishFormat.format((java.util.Date)obj);
        }
        return obj;
    }
    
    public String getColumnName(int columnIndex) {
        return Event.getColumnName(mapping[columnIndex]);
    }
    
    public void updateColumns() {
        Set columns = Config.getGridColumns();
        int size = columns.size();
        if (0 == size) {
            columns = Config.getDefaultGridColumns();
            size = columns.size();
        }
        mapping = new int[size];
        int j = 0;
        for (Iterator i = columns.iterator(); i.hasNext(); )
            mapping[j++] = ((Integer)i.next()).intValue();
        fireTableStructureChanged();
    }
    
    public void startMonitoring() {
        eventsList.addListDataListener(this);
    }
    
    public void stopMonitoring() {
        eventsList.removeListDataListener(this);
    }
    
    public void contentsChanged(javax.swing.event.ListDataEvent e) {
        fireTableDataChanged();
    }
    
    public void intervalAdded(javax.swing.event.ListDataEvent e) {
        fireTableRowsInserted(e.getIndex0(), e.getIndex1());
    }
    
    public void intervalRemoved(javax.swing.event.ListDataEvent e) {
        fireTableRowsDeleted(e.getIndex0(), e.getIndex1());
    }
    
}
