/*
 * LookAndFeel.java
 *
 * Created on 17  2003 ., 14:35
 */

package com.fn.BikersLog;


import java.util.Enumeration;
import java.util.ResourceBundle;
import java.util.Vector;
import javax.swing.LookAndFeel;
import javax.swing.UIManager;


/**
 *
 * @author  asso
 */
public class LookAndFeelHelper {

    public static boolean isLookAndFeelSupported(UIManager.LookAndFeelInfo lafi) {
        try {
            Class lnfClass = Class.forName(lafi.getClassName());
            LookAndFeel lookAndFeel = (LookAndFeel)lnfClass.newInstance();
            return lookAndFeel.isSupportedLookAndFeel();
        } catch (Exception e) { }
        return false;
    }
    
    private static LookAndFeel createLookAndFeel(String className) {
        try {
            Class lnfClass = Class.forName(className);
            LookAndFeel lookAndFeel = (LookAndFeel)lnfClass.newInstance();
            if (lookAndFeel.isSupportedLookAndFeel())
                return lookAndFeel;
        } catch (Exception e) { }
        return null;
    }

    private static boolean isLafInstalled(String className) {
        UIManager.LookAndFeelInfo lfInfo[] = UIManager.getInstalledLookAndFeels();
        for (int i = 0; i < lfInfo.length; i++)
            if (lfInfo[i].getClassName().equals(className))
                return true;
        return false;
    }
    
    public static void preloadLookAndFeels() {
        boolean macOSX = System.getProperty("os.name").startsWith("Mac OS X");
        try {
            ResourceBundle bundle = ResourceBundle.getBundle("com/fn/BikersLog/plaf");
            Enumeration keys = bundle.getKeys();
            while (keys.hasMoreElements()) {
                String className = bundle.getString((String)keys.nextElement());

                // disable Kunstoff look and feel on MacOS X
                if (macOSX && (null != className) && 
                        className.equals("com.incors.plaf.kunststoff.KunststoffLookAndFeel"))
                    continue;

                if (! isLafInstalled(className)) {
                    LookAndFeel lf = createLookAndFeel(className);
                    if ((lf != null) && (! isLafInstalled(className)))
                        UIManager.installLookAndFeel(lf.getName(), className);
                }
            }
        } catch (Exception e) { }
    }
    
    public static void setLookAndFeel(String name) {
        if (name.equals("Default"))
            return;

        boolean macOSX = System.getProperty("os.name").startsWith("Mac OS X");
        if (macOSX && (null != name) && name.equals("Kunststoff"))
            return;
        
        UIManager.LookAndFeelInfo lfInfo[] = UIManager.getInstalledLookAndFeels();
        for (int i = 0; i < lfInfo.length; i++)
            if (lfInfo[i].getName().equals(name)) {
                try {
                    UIManager.setLookAndFeel(lfInfo[i].getClassName());
                } catch (Exception e) { }
                return;
            }
    }
    
    public static Vector getLafList() {
        Vector v = new Vector();
        v.add("Default");
        UIManager.LookAndFeelInfo lfInfo[] = UIManager.getInstalledLookAndFeels();
        int len = lfInfo.length;
        for (int i = 0; i < len; i++)
            if (LookAndFeelHelper.isLookAndFeelSupported(lfInfo[i]))
                v.add(lfInfo[i].getName());
        return v;
    }
    
    public static String getCurrentLafName() {
        String s = javax.swing.UIManager.getLookAndFeel().getClass().getName();
        UIManager.LookAndFeelInfo lfInfo[] = UIManager.getInstalledLookAndFeels();
        int len = lfInfo.length;
        for (int i = 0; i < len; i++)
            if (lfInfo[i].getClassName().equals(s))
                return lfInfo[i].getName();
        return "";
    }
}
