/*
 * MicroTable.java
 *
 * Created on 11  2004 ., 14:41
 */

package com.fn.BikersLog;


import java.awt.Component;
import java.awt.Dimension;
import java.awt.Graphics2D;
import javax.swing.ImageIcon;


/**
 *
 * @author  asso
 */
public class MicroTable {
    
    private MicroTableModel model;
    private int[] widths;
    private int[] heights;
    private int totalHeight;
    private static final int HOR_GAP = 5;
    private static final int VER_GAP = 0;
    
    /** Creates a new instance of MicroTable */
    public MicroTable() {
    }
    
    public void draw(Component comp, Graphics2D g2, int x, int y, int width, 
            int height) 
    {
        if (null == model)
            return;
        
        int columns = model.getColumnCount();
        int rows = model.getRowCount();
        if ((columns < 1) || (rows < 1))
            return;
        
        calculateSize(g2);
        
        int offsetY = (height - totalHeight) / 2 + y;
        if (offsetY < y)
            offsetY = y;
        for (int j = 0; j < rows; j++) {
            int offsetX = x;
            for (int i = 0; i < columns; i++) {
//g2.drawRect(offsetX, offsetY, widths[i], heights[j]);
                drawItem(comp, g2, offsetX, offsetY, model.getItem(j, i));
                offsetX += widths[i] + HOR_GAP;
            }
            offsetY += heights[j] += VER_GAP;
        }
    }
    
    public void setModel(MicroTableModel model) {
        this.model = model;
    }
    
    private void resetSize() {
        int columns = model.getColumnCount();
        if (columns < 1)
            return;
        if ((null == widths) || (widths.length < columns))
            widths = new int[columns];
        for (int i = 0; i < columns; i++)
            widths[i] = 0;
        
        int rows = model.getRowCount();
        if (rows < 1)
            return;
        if ((null == heights) || (heights.length < rows))
            heights = new int[rows];
        for (int i = 0; i < rows; i++)
            heights[i] = 0;
    }
    
    private void calculateSize(Graphics2D g2) {
        resetSize();
        int columns = model.getColumnCount();
        int rows = model.getRowCount();
        
        Dimension bounds = new Dimension();
        for (int j = 0; j < rows; j++) {
            for (int i = 0; i < columns; i++) {
                Object obj = model.getItem(j, i);
                if (null != obj) {
                    calcItemBounds(g2, obj, bounds);
                    if (widths[i] < bounds.width)
                        widths[i] = bounds.width;
                    if (heights[j] < bounds.height)
                        heights[j] = bounds.height;
                }
            }
        }
        
        totalHeight = 0;
        for (int j = 0; j < rows; j++)
            totalHeight += heights[j];
        totalHeight += VER_GAP * (rows - 1);
    }
    
    private void calcItemBounds(Graphics2D g2, Object obj, Dimension bounds) {
        if (obj instanceof ImageIcon) {
            ImageIcon image = (ImageIcon)obj;
            bounds.width = image.getIconWidth();
            bounds.height = image.getIconHeight();
        } else {
            try {
                String s = obj.toString();
                bounds.width = g2.getFontMetrics().stringWidth(s);
                bounds.height = g2.getFontMetrics().getHeight();
            } catch (Exception e) {
                bounds.width = 0;
                bounds.height = 0;
            }
        }
    }
    
    private void drawItem(Component comp, Graphics2D g2, int x, int y, Object obj) {
        if (null == obj)
            return;
        if (obj instanceof ImageIcon) {
            ImageIcon image = (ImageIcon)obj;
            image.paintIcon(comp, g2, x, y);
        } else {
            try {
                String s = obj.toString();
                g2.drawString(s, x, y + g2.getFontMetrics().getAscent());
            } catch (Exception e) { }
        }
    }
}
