/*
 * OptionsDepot.java
 *
 * Created on 6  2004 ., 19:58
 */

package com.fn.BikersLog;


import java.awt.Color;
import java.awt.Font;
import java.awt.Rectangle;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.util.Iterator;
import java.util.List;
import java.util.Properties;
import java.util.Set;
import java.util.StringTokenizer;


/**
 *
 * @author  asso
 */
public class OptionsDepot {

    private static Properties properties;

    static {
        load();
    }

    public static Font getFont(String name, Font dflt) {
        String fontDescr = properties.getProperty(name);
        if ((fontDescr == null) || fontDescr.equals(""))
            return dflt;
        try {
            Font fnt = Font.decode(fontDescr);
            if (fnt == null)
                return dflt;
            else
                return fnt;
        } catch (Exception e) {
            e.printStackTrace();
            System.out.println("Error decoding font: " + e.getMessage());
            return dflt;
        }
    }
    
    public static Color getColor(String name, Color dflt) {
        String colorDescr = properties.getProperty(name);
        if ((colorDescr == null) || colorDescr.equals(""))
            return dflt;
        try {
            Color c = Color.decode(colorDescr);
            if (c == null)
                return dflt;
            else
                return c;
        } catch (Exception e) {
            e.printStackTrace();
            System.out.println("Error decoding color: " + e.getMessage());
            return dflt;
        }
    }
    
    public static int getInteger(String name, int dflt) {
        String val = properties.getProperty(name);
        if ((val == null) || val.equals(""))
            return dflt;
        try {
            return Integer.parseInt(val);
        } catch (Exception e) {
            e.printStackTrace();
            System.out.println("Error decoding integer: " + e.getMessage());
            return dflt;
        }
    }
    
    public static Rectangle getRectangle(String name, Rectangle dflt) {
        int x = getInteger(name + ".x", (int)dflt.getX());
        int y = getInteger(name + ".y", (int)dflt.getY());
        int width = getInteger(name + ".width", (int)dflt.getWidth());
        int height = getInteger(name + ".height", (int)dflt.getHeight());
        return new Rectangle(x, y, width, height);
    }
    
    public static String getString(String name, String dflt) {
        return properties.getProperty(name, dflt);
    }

    public static List getStringsList(String name, List dflt) {
        List l = new java.util.LinkedList();
        int cnt = getInteger(name + ".count", -1);
        if (cnt < 0)
            return dflt;
        for (int i = 0; i < cnt; i++)
            l.add(getString(name + "." + Integer.toString(i), ""));
        return l;
    }
    
    public static boolean getBoolean(String name, boolean dflt) {
        int v = dflt ? 1 : 0;
        return getInteger(name, v) == 1;
    }

    public static Set getIntegerSet(String name, Set dflt) {
        String s = properties.getProperty(name, null);
        if (null == s)
            return dflt;
        Set set = new java.util.TreeSet();
        StringTokenizer st = new StringTokenizer(s, " ,\t");
        while (st.hasMoreTokens()) {
            try {
                set.add(new Integer(st.nextToken()));
            } catch (Exception e) {
                return dflt;
            }
        }
        return set;
    }
    
    public static int[] getIntegerArr(String name, int[] dflt) {
        String s = properties.getProperty(name, null);
        if (null == s)
            return dflt;
        StringTokenizer st = new StringTokenizer(s, " ,\t");
        int cnt = st.countTokens();
        int[] arr = new int[cnt];
        int i = 0;
        while (st.hasMoreTokens()) {
            try {
                arr[i] = Integer.parseInt(st.nextToken());
            } catch (Exception e) {
                return dflt;
            }
            i++;
        }
        return arr;
    }
    
    public static boolean[] getBooleanArr(String name, boolean[] dflt) {
        String s = properties.getProperty(name, null);
        if (null == s)
            return dflt;
        StringTokenizer st = new StringTokenizer(s, " ,\t");
        int cnt = st.countTokens();
        boolean[] arr = new boolean[cnt];
        int i = 0;
        while (st.hasMoreTokens()) {
            try {
                arr[i] = ! st.nextToken().equals("0");
            } catch (Exception e) {
                return dflt;
            }
            i++;
        }
        return arr;
    }
    
    private static void loadFromFile(File dir, String fileName) throws Exception {
        File f = new File(dir, fileName);
        FileInputStream in = new FileInputStream(f);
        properties = new Properties();
        properties.load(in);
        in.close();
    }
    
    public static void load() {
        try {
            File dir = new java.io.File(System.getProperty("user.home"));
            try {
                loadFromFile(dir, ".sportTool");
            } catch (Exception e) {
                loadFromFile(dir, ".bikersLog");
            }
        } catch (Exception e) {
            properties = new Properties();
        }
    }
    
    public static void setColor(String name, Color color) {
        properties.put(name, "0x" + Integer.toHexString(color.getRGB() & 0x00FFFFFF));
    }
    
    public static void setFont(String name, Font font) {
        String family = font.getFamily();
        String size = Integer.toString(font.getSize());
        String styleName;
        int style = font.getStyle();
        switch (style) {
            case Font.PLAIN: styleName = ""; break;
            case Font.BOLD: styleName = "BOLD"; break;
            case Font.ITALIC: styleName = "ITALIC"; break;
            default: styleName = "BOLDITALIC";
        }
        properties.put(name, family + "-" + styleName + "-" + size);
    }
    
    public static void setInteger(String name, int i) {
        properties.put(name, Integer.toString(i));
    }
    
    public static void setRectangle(String name, Rectangle rect) {
        setInteger(name + ".x", (int)rect.getX());
        setInteger(name + ".y", (int)rect.getY());
        setInteger(name + ".width", (int)rect.getWidth());
        setInteger(name + ".height", (int)rect.getHeight());
    }
    
    public static void setString(String name, String s) {
        properties.put(name, s);
    }
    
    public static void setStringsList(String name, List list) {
        setInteger(name + ".count", list.size());
        int num = 0;
        for (Iterator i = list.iterator(); i.hasNext(); ) {
            setString(name + "." + Integer.toString(num), (String)i.next());
            num++;
        }
    }
    
    public static void setBoolean(String name, boolean value) {
        int v = value ? 1 : 0;
        setInteger(name, v);
    }
    
    public static void setIntegerSet(String name, Set set) {
        StringBuffer sb = new StringBuffer();
        boolean first = true;
        for (Iterator i = set.iterator(); i.hasNext(); ) {
            if (! first)
                sb.append(',');
            else
                first = false;
            sb.append(((Integer)i.next()).toString());
        }
        setString(name, sb.toString());
    }

    public static void setIntegerArr(String name, int[] arr) {
        if (null == arr) {
            setString(name, "");
            return;
        }
        int len = arr.length;
        StringBuffer sb = new StringBuffer();
        boolean first = true;
        for (int i = 0; i < len; i++) {
            if (! first)
                sb.append(',');
            else
                first = false;
            sb.append(Integer.toString(arr[i]));
        }
        setString(name, sb.toString());
    }

    public static void setBooleanArr(String name, boolean[] arr) {
        if (null == arr) {
            setString(name, "");
            return;
        }
        int len = arr.length;
        StringBuffer sb = new StringBuffer();
        boolean first = true;
        for (int i = 0; i < len; i++) {
            if (! first)
                sb.append(',');
            else
                first = false;
            sb.append(arr[i] ? '1' : '0');
        }
        setString(name, sb.toString());
    }
    
    public static void save() throws IOException {
        java.io.File dir = new java.io.File(System.getProperty("user.home"));
        File f = new java.io.File(dir, ".sportTool");
        FileOutputStream out = new FileOutputStream(f);
        properties.store(out, "--- SportTool Configuration file ---");
        out.close();
    }
}
