/*
 * TrainEvent.java
 *
 * Created on 12  2003 ., 21:49
 */

package com.fn.BikersLog;


import java.text.DateFormat;
import java.util.Date;
import javax.swing.ImageIcon;
import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.Text;


/**
 *
 * @author  asso
 */
public class RideEvent extends Event {
    
    private Bike bike = null;
    private Course course = null;
    private double distance;
    private boolean looped = false;
    private int type = 1;
    private Date finish = new Date();
    private int elapsed;
    private int windDirection = 1;
    private int windSpeed;
    private int temperature;
    private double avgSpeed;
    private double maxSpeed;
    private int heartRate;
    private String notes;
    private static String rideType = I18n.getMsg("ride.type");
    private static ImageIcon icon = null;
    private double cadence;
    private double wattage;
    private double weight;
    private double calories;
    
    /** Creates a new instance of TrainEvent */
    public RideEvent() {
    }
    
    public RideEvent(Element ride, Log log) {
        bike = log.getBikesList().getById(DOMUtil.getSubtagData(ride, "bike", 1));
        bike.addRef();
        course = log.getCoursesList().getById(DOMUtil.getSubtagData(ride, "course", 1));
        course.addRef();
        distance = DOMUtil.getSubtagData(ride, "distance", 0.0);
        looped = DOMUtil.getSubtagData(ride, "looped", false);
        type = DOMUtil.getSubtagData(ride, "rideType", 1);
        setStart(DOMUtil.getSubtagData(ride, "start", new Date()));
        finish = DOMUtil.getSubtagData(ride, "finish", new Date());
        elapsed = DOMUtil.getSubtagData(ride, "elapsed", 0);
        windDirection = DOMUtil.getSubtagData(ride, "windDirection", 1);
        windSpeed = DOMUtil.getSubtagData(ride, "windSpeed", 0);
        temperature = DOMUtil.getSubtagData(ride, "temperature", 0);
        avgSpeed = DOMUtil.getSubtagData(ride, "avgSpeed", 0.0);
        maxSpeed = DOMUtil.getSubtagData(ride, "maxSpeed", 0.0);
        heartRate = DOMUtil.getSubtagData(ride, "heartRate", 0);
        notes = DOMUtil.getSubtagData(ride, "notes", "");
        cadence = DOMUtil.getSubtagData(ride, "cadence", 0.0);
        wattage = DOMUtil.getSubtagData(ride, "wattage", 0.0);
        weight = DOMUtil.getSubtagData(ride, "weight", 0.0);
        calories = DOMUtil.getSubtagData(ride, "calories", 0.0);
    }
    
    public void setCourse(Course c) {
        if (course != null)
            course.delRef();
        if (c != null)
            c.addRef();
        course = c;
    }
    
    public Course getCourse() {
        return course;
    }
    
    public void setBike(Bike b) {
        if (bike != null)
            bike.delRef();
        if (b != null)
            b.addRef();
        bike = b;
    }
    
    public Bike getBike() {
        return bike;
    }
    
    public double getDistance() {
        return distance;
    }
    
    public void setDistance(double distance) {
        this.distance = distance;
    }
    
    public boolean isLooped() {
        return looped;
    }
    
    public void setLooped(boolean looped) {
        this.looped = looped;
    }
    
    public int getRideType() {
        return type;
    }
    
    public String getRideTypeDescr() {
        return I18n.getMsg("rideType." + Integer.toString(type));
    }
    
    public void setRideType(int type) {
        this.type = type;
    }
    
    public java.util.Date getFinish() {
        return finish;
    }
    
    public void setFinish(java.util.Date finish) {
        this.finish = finish;
    }
    
    public int getElapsed() {
        return elapsed;
    }
    
    public void setElapsed(int elapsed) {
        this.elapsed = elapsed;
    }
    
    public int getWindDirection() {
        return windDirection;
    }
    
    public void setWindDirection(int windDirection) {
        this.windDirection = windDirection;
    }
    
    public int getWindSpeed() {
        return windSpeed;
    }
    
    public void setWindSpeed(int windSpeed) {
        this.windSpeed = windSpeed;
    }
    
    public int getTemperature() {
        return temperature;
    }
    
    public void setTemperature(int temperature) {
        this.temperature = temperature;
    }
    
    public double getAvgSpeed() {
        return avgSpeed;
    }
    
    public void setAvgSpeed(double avgSpeed) {
        this.avgSpeed = avgSpeed;
    }
    
    public double getMaxSpeed() {
        return maxSpeed;
    }
    
    public void setMaxSpeed(double maxSpeed) {
        this.maxSpeed = maxSpeed;
    }
    
    public int getHeartRate() {
        return heartRate;
    }
    
    public void setHeartRate(int heartRate) {
        this.heartRate = heartRate;
    }
    
    public java.lang.String getNotes() {
        return notes;
    }
    
    public void setNotes(java.lang.String notes) {
        this.notes = notes;
    }
    
    public String toString() {
        DateFormat df = DateFormat.getDateTimeInstance(DateFormat.SHORT, DateFormat.SHORT);
        StringBuffer sb = new StringBuffer();
        sb.append(df.format(getStart())).append(' ').append(rideType);
        sb.append(' ').append(Utils.intervalToTime(elapsed)).append(", ");
        sb.append(Utils.doubleToStr(Units.fromStdBDist(distance)));
        sb.append(Units.getBDist().getShortName());
        sb.append(", ");
        sb.append(Utils.doubleToStr(Units.fromStdSpeed(avgSpeed)));
        sb.append(Units.getSpeed().getShortName());
        return sb.toString();
    }
    
    public void save(Document document, Element root) {
        Element ride = DOMUtil.addElement(document, root, "event");
        DOMUtil.addDataElement(document, ride, "type", "ride");
        DOMUtil.addDataElement(document, ride, "start", getStart());
        DOMUtil.addDataElement(document, ride, "finish", finish);
        DOMUtil.addDataElement(document, ride, "bike", bike.getId());
        DOMUtil.addDataElement(document, ride, "course", course.getId());
        DOMUtil.addDataElement(document, ride, "distance", distance);
        DOMUtil.addDataElement(document, ride, "looped", looped);
        DOMUtil.addDataElement(document, ride, "rideType", type);
        DOMUtil.addDataElement(document, ride, "elapsed", elapsed);
        DOMUtil.addDataElement(document, ride, "windDirection", windDirection);
        DOMUtil.addDataElement(document, ride, "windSpeed", windSpeed);
        DOMUtil.addDataElement(document, ride, "temperature", temperature);
        DOMUtil.addDataElement(document, ride, "avgSpeed", avgSpeed);
        DOMUtil.addDataElement(document, ride, "maxSpeed", maxSpeed);
        DOMUtil.addDataElement(document, ride, "heartRate", heartRate);
        DOMUtil.addDataElement(document, ride, "notes", notes);
        DOMUtil.addDataElement(document, ride, "cadence", cadence);
        DOMUtil.addDataElement(document, ride, "wattage", wattage);
        DOMUtil.addDataElement(document, ride, "weight", weight);
        DOMUtil.addDataElement(document, ride, "calories", calories);
    }    
    
    public void onRemove() {
        bike.delRef();
        course.delRef();
    }
    
    public ImageIcon getIcon() {
        if (null == icon)
            icon = new ImageIcon(getClass().getResource("/com/fn/BikersLog/img/bike.png"));
        return icon;
    }
    
    public Object getColumnData(int column) {
        switch (column) {
            case Event.COLUMN_AVG_SPEED:
                return Utils.doubleToStr(Units.fromStdSpeed(avgSpeed));
            case Event.COLUMN_DISTANCE:
                return Utils.doubleToStr(Units.fromStdBDist(distance));
            case Event.COLUMN_EFFORT:
                return getRideTypeDescr();
            case Event.COLUMN_ELAPSED:
                return Utils.intervalToTime(elapsed);
            case Event.COLUMN_EQUIPMENT:
                return bike.getName();
            case Event.COLUMN_FINISH:
                return finish;
            case Event.COLUMN_HEART_RATE:
                return new Integer(heartRate);
            case Event.COLUMN_MAX_SPEED:
                return Utils.doubleToStr(Units.fromStdSpeed(maxSpeed));
            case Event.COLUMN_NOTES:
                return notes;
            case Event.COLUMN_ROUTE:
                return course.getName();
            case Event.COLUMN_TEMPERATURE:
                return new Integer(temperature);
            case Event.COLUMN_TYPE:
                return rideType;
            case Event.COLUMN_WIND_DIRECTION:
                return I18n.getMsg("windDir." + Integer.toString(windDirection));
            case Event.COLUMN_WIND_SPEED:
                return I18n.getMsg("windSpeed." + Integer.toString(windSpeed));
            case Event.COLUMN_CADENCE:
                return Utils.doubleToStr(cadence);
            case Event.COLUMN_WEIGHT:
                return Utils.doubleToStr(Units.fromStdWeight(weight));
            case Event.COLUMN_CALORIES:
                return Utils.doubleToStr(calories);
            case Event.COLUMN_WATTAGE:
                return Utils.doubleToStr(wattage);
            default:
                return super.getColumnData(column);
        }
    }
    
    public double getCadence() {
        return cadence;
    }
    
    public void setCadence(double cadence) {
        this.cadence = cadence;
    }
    
    public double getWattage() {
        return wattage;
    }
    
    public void setWattage(double wattage) {
        this.wattage = wattage;
    }
    
    public double getWeight() {
        return weight;
    }
    
    public void setWeight(double weight) {
        this.weight = weight;
    }
    
    public double getCalories() {
        return calories;
    }
    
    public void setCalories(double calories) {
        this.calories = calories;
    }
    
}
