/*
 * RideWindow.java
 *
 * Created on 13  2003 ., 12:29
 */

package com.fn.BikersLog;


import java.text.NumberFormat;
import java.text.DateFormat;
import java.util.Date;
import javax.swing.DefaultComboBoxModel;
import javax.swing.JOptionPane;


/**
 *
 * @author  asso
 */
public class SwimmingWindow extends javax.swing.JDialog {
    
    private Log log;
    private SwimmingEvent event;
    private boolean okPressed = false;
    private DateFormat dateFormat;
    
    /** Creates new form RideWindow */
    public SwimmingWindow(java.awt.Frame parent, Log log, SwimmingEvent se, 
                boolean editing) 
    {
        super(parent, true);
        if (editing)
            setTitle(I18n.getMsg("swimmingForm.editTitle"));
        else
            setTitle(I18n.getMsg("swimmingForm.newTitle"));
        this.log = log;
        event = se;
        dateFormat = DateFormat.getDateTimeInstance(DateFormat.SHORT, DateFormat.SHORT);
        dateFormat.setLenient(false);
        initComponents();
        setValues();
        Utils.centerWindow(this, parent);
    }
    
    private void setValues() {
        styleCombo.setSelectedIndex(event.getStyle() - 1);
        distanceTextField.setText(Utils.doubleToStr(Units.fromStdSDist(event.getDistance())));
        startCalendar.setDate(event.getStart());
        startTime.setTime(event.getStart());
        finishCalendar.setDate(event.getFinish());
        finishTime.setTime(event.getFinish());
        elapsedTextField.setText(Utils.intervalToTime(event.getElapsed()));
        speedTextField.setText(Utils.doubleToStr(Units.fromStdSpeed(event.getAvgSpeed())));
        hrTextField.setText(Integer.toString(event.getHeartRate()));
        notesTextArea.setText(event.getNotes());
        weightTextField.setText(Utils.doubleToStr(
                Units.fromStdWeight(event.getWeight())));
        caloriesTextField.setText(Utils.doubleToStr(event.getCalories()));
    }
    
    private int getInterval(String text, String exceptionKey) throws Exception {
        int interval;
        try {
            interval = Utils.timetoInterval(text);
        } catch (Exception e) {
            throw new Exception(I18n.getMsg(exceptionKey));
        }
        if (interval < 0)
            throw new Exception(I18n.getMsg(exceptionKey));
        else
            return interval;
    }
    
    private void getValues() throws Exception {
        double distance = Units.toStdSDist(
                    Utils.parseDouble(distanceTextField.getText(), 
                    "rowForm.invalidDistance"));
        int elapsed = getInterval(elapsedTextField.getText(), "rowForm.invalidInterval");
        double avgSpeed = Units.toStdSpeed(Utils.parseDouble(speedTextField.getText(), 
                    "rowForm.invalidSpeed"));
        int heartRate = Utils.parseInt(hrTextField.getText(), "rowForm.invalidHR");
        double weight = Utils.parseDouble(weightTextField.getText(), 
                    "generic.invalidWeight");
        double calories = Utils.parseDouble(caloriesTextField.getText(), 
                    "rideForm.invalidCalories");
        
        event.setStyle(styleCombo.getSelectedIndex() + 1);
        event.setDistance(distance);
        event.setStart(Utils.calendarToDateTime(startCalendar, startTime));
        event.setFinish(Utils.calendarToDateTime(finishCalendar, finishTime));
        event.setElapsed(elapsed);
        event.setAvgSpeed(avgSpeed);
        event.setHeartRate(heartRate);
        event.setNotes(notesTextArea.getText());
        event.setWeight(Units.toStdWeight(weight));
        event.setCalories(calories);
    }
    
    /** This method is called from within the constructor to
     * initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is
     * always regenerated by the Form Editor.
     */
    private void initComponents() {//GEN-BEGIN:initComponents
        java.awt.GridBagConstraints gridBagConstraints;

        jPanel1 = new javax.swing.JPanel();
        okBtn = new javax.swing.JButton();
        cancelBtn = new javax.swing.JButton();
        jPanel6 = new javax.swing.JPanel();
        jTabbedPane1 = new javax.swing.JTabbedPane();
        jPanel2 = new javax.swing.JPanel();
        jLabel2 = new javax.swing.JLabel();
        styleCombo = new javax.swing.JComboBox();
        jLabel8 = new javax.swing.JLabel();
        elapsedTextField = new javax.swing.JTextField();
        calcElapsedTimeBtn1 = new javax.swing.JButton();
        jLabel12 = new javax.swing.JLabel();
        finishCalendar = new org.rapla.components.calendar.RaplaCalendar();
        finishTime = new org.rapla.components.calendar.RaplaTime();
        jLabel18 = new javax.swing.JLabel();
        startCalendar = new org.rapla.components.calendar.RaplaCalendar();
        startTime = new org.rapla.components.calendar.RaplaTime();
        jPanel4 = new javax.swing.JPanel();
        jLabel3 = new javax.swing.JLabel();
        distanceTextField = new javax.swing.JTextField();
        jLabel4 = new javax.swing.JLabel();
        speedTextField = new javax.swing.JTextField();
        jLabel9 = new javax.swing.JLabel();
        hrTextField = new javax.swing.JTextField();
        calcAvgSpeedBtn = new javax.swing.JButton();
        jLabel16 = new javax.swing.JLabel();
        weightTextField = new javax.swing.JTextField();
        jLabel17 = new javax.swing.JLabel();
        caloriesTextField = new javax.swing.JTextField();
        distLabel = new javax.swing.JLabel();
        avgSpeedLabel = new javax.swing.JLabel();
        weightLabel = new javax.swing.JLabel();
        jPanel7 = new javax.swing.JPanel();
        jScrollPane1 = new javax.swing.JScrollPane();
        notesTextArea = new javax.swing.JTextArea();

        addWindowListener(new java.awt.event.WindowAdapter() {
            public void windowClosing(java.awt.event.WindowEvent evt) {
                closeDialog(evt);
            }
        });

        jPanel1.setLayout(new java.awt.FlowLayout(java.awt.FlowLayout.CENTER, 8, 8));

        okBtn.setText(I18n.getMsg("generic.ok"));
        okBtn.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                okBtnActionPerformed(evt);
            }
        });

        jPanel1.add(okBtn);

        cancelBtn.setText(I18n.getMsg("generic.cancel"));
        cancelBtn.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                cancelBtnActionPerformed(evt);
            }
        });

        jPanel1.add(cancelBtn);

        getContentPane().add(jPanel1, java.awt.BorderLayout.SOUTH);

        jPanel6.setLayout(new javax.swing.BoxLayout(jPanel6, javax.swing.BoxLayout.X_AXIS));

        jPanel6.setBorder(new javax.swing.border.EmptyBorder(new java.awt.Insets(8, 8, 0, 8)));
        jPanel2.setLayout(new java.awt.GridBagLayout());

        jPanel2.setBorder(new javax.swing.border.EmptyBorder(new java.awt.Insets(8, 8, 8, 8)));
        jLabel2.setLabelFor(styleCombo);
        jLabel2.setText(I18n.getMsg("swimmingForm.swimming.style"));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.insets = new java.awt.Insets(4, 0, 4, 4);
        jPanel2.add(jLabel2, gridBagConstraints);

        styleCombo.setModel(Utils.createPropEnumComboModel("swimmingStyle"));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.gridwidth = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 0);
        jPanel2.add(styleCombo, gridBagConstraints);

        jLabel8.setLabelFor(elapsedTextField);
        jLabel8.setText(I18n.getMsg("rideForm.timing.elapsed"));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 3;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.insets = new java.awt.Insets(4, 0, 0, 4);
        jPanel2.add(jLabel8, gridBagConstraints);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 3;
        gridBagConstraints.gridwidth = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.weightx = 2.0;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 0, 0);
        jPanel2.add(elapsedTextField, gridBagConstraints);

        calcElapsedTimeBtn1.setIcon(new javax.swing.ImageIcon(getClass().getResource("/com/fn/BikersLog/img/Refresh16.gif")));
        calcElapsedTimeBtn1.setToolTipText(I18n.getMsg("rideForm.timing.calcLength"));
        calcElapsedTimeBtn1.setAlignmentX(0.5F);
        calcElapsedTimeBtn1.setMinimumSize(new java.awt.Dimension(18, 18));
        calcElapsedTimeBtn1.setPreferredSize(new java.awt.Dimension(24, 24));
        calcElapsedTimeBtn1.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                calcElapsedTimeBtn1ActionPerformed(evt);
            }
        });

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 3;
        gridBagConstraints.gridy = 3;
        gridBagConstraints.insets = new java.awt.Insets(0, 8, 0, 0);
        jPanel2.add(calcElapsedTimeBtn1, gridBagConstraints);

        jLabel12.setText(I18n.getMsg("rideForm.timing.finish"));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.insets = new java.awt.Insets(4, 0, 4, 4);
        jPanel2.add(jLabel12, gridBagConstraints);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.SOUTH;
        gridBagConstraints.weightx = 1.0;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 4);
        jPanel2.add(finishCalendar, gridBagConstraints);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 2;
        gridBagConstraints.gridy = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.SOUTH;
        gridBagConstraints.weightx = 1.0;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 0);
        jPanel2.add(finishTime, gridBagConstraints);

        jLabel18.setText(I18n.getMsg("rideForm.timing.start"));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.insets = new java.awt.Insets(4, 0, 4, 4);
        jPanel2.add(jLabel18, gridBagConstraints);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.SOUTH;
        gridBagConstraints.weightx = 1.0;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 4);
        jPanel2.add(startCalendar, gridBagConstraints);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 2;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.SOUTH;
        gridBagConstraints.weightx = 1.0;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 0);
        jPanel2.add(startTime, gridBagConstraints);

        jTabbedPane1.addTab(I18n.getMsg("swimming.type"), jPanel2);

        jPanel4.setLayout(new java.awt.GridBagLayout());

        jPanel4.setBorder(new javax.swing.border.EmptyBorder(new java.awt.Insets(8, 8, 8, 8)));
        jLabel3.setLabelFor(distanceTextField);
        jLabel3.setText(I18n.getMsg("rideForm.results.distance"));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.insets = new java.awt.Insets(0, 0, 4, 4);
        jPanel4.add(jLabel3, gridBagConstraints);

        distanceTextField.setPreferredSize(new java.awt.Dimension(150, 19));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(0, 4, 4, 0);
        jPanel4.add(distanceTextField, gridBagConstraints);

        jLabel4.setLabelFor(speedTextField);
        jLabel4.setText(I18n.getMsg("rideForm.results.speed"));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.insets = new java.awt.Insets(4, 0, 4, 4);
        jPanel4.add(jLabel4, gridBagConstraints);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 0);
        jPanel4.add(speedTextField, gridBagConstraints);

        jLabel9.setLabelFor(hrTextField);
        jLabel9.setText(I18n.getMsg("rideForm.results.hr"));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 3;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.insets = new java.awt.Insets(4, 0, 4, 4);
        jPanel4.add(jLabel9, gridBagConstraints);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 3;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.weightx = 1.0;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 0);
        jPanel4.add(hrTextField, gridBagConstraints);

        calcAvgSpeedBtn.setIcon(new javax.swing.ImageIcon(getClass().getResource("/com/fn/BikersLog/img/Refresh16.gif")));
        calcAvgSpeedBtn.setToolTipText(I18n.getMsg("rideForm.results.calcSpeed"));
        calcAvgSpeedBtn.setAlignmentX(0.5F);
        calcAvgSpeedBtn.setMinimumSize(new java.awt.Dimension(18, 18));
        calcAvgSpeedBtn.setPreferredSize(new java.awt.Dimension(24, 24));
        calcAvgSpeedBtn.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                calcAvgSpeedBtnActionPerformed(evt);
            }
        });

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 3;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.insets = new java.awt.Insets(0, 8, 0, 0);
        jPanel4.add(calcAvgSpeedBtn, gridBagConstraints);

        jLabel16.setText(I18n.getMsg("rideForm.results.weight"));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 5;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.insets = new java.awt.Insets(4, 0, 4, 4);
        jPanel4.add(jLabel16, gridBagConstraints);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 5;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 0);
        jPanel4.add(weightTextField, gridBagConstraints);

        jLabel17.setText(I18n.getMsg("rideForm.results.calories"));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 6;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.insets = new java.awt.Insets(4, 0, 0, 4);
        jPanel4.add(jLabel17, gridBagConstraints);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 6;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 0, 0);
        jPanel4.add(caloriesTextField, gridBagConstraints);

        distLabel.setText(Units.getSDist().getShortName());
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.insets = new java.awt.Insets(0, 4, 4, 0);
        jPanel4.add(distLabel, gridBagConstraints);

        avgSpeedLabel.setText(Units.getSpeed().getShortName());
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 2;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 0);
        jPanel4.add(avgSpeedLabel, gridBagConstraints);

        weightLabel.setText(Units.getWeight().getShortName());
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 2;
        gridBagConstraints.gridy = 5;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 0);
        jPanel4.add(weightLabel, gridBagConstraints);

        jTabbedPane1.addTab(I18n.getMsg("rideForm.results"), jPanel4);

        jPanel7.setLayout(new java.awt.BorderLayout());

        jPanel7.setBorder(new javax.swing.border.EmptyBorder(new java.awt.Insets(8, 8, 8, 8)));
        jScrollPane1.setPreferredSize(new java.awt.Dimension(380, 200));
        notesTextArea.setLineWrap(true);
        notesTextArea.setWrapStyleWord(true);
        jScrollPane1.setViewportView(notesTextArea);

        jPanel7.add(jScrollPane1, java.awt.BorderLayout.CENTER);

        jTabbedPane1.addTab(I18n.getMsg("rideForm.notes"), jPanel7);

        jPanel6.add(jTabbedPane1);

        getContentPane().add(jPanel6, java.awt.BorderLayout.CENTER);

        pack();
    }//GEN-END:initComponents

    private void calcElapsedTimeBtn1ActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_calcElapsedTimeBtn1ActionPerformed
        Date start = Utils.calendarToDateTime(startCalendar, startTime);
        Date finish = Utils.calendarToDateTime(finishCalendar, finishTime);
        int interval = (int)((finish.getTime() - start.getTime()) / 1000);
        if (interval < 0) {
            JOptionPane.showMessageDialog(this, I18n.getMsg("rideForm.invalidStartFinish"),
                    I18n.getMsg("mainWindow.title"), JOptionPane.ERROR_MESSAGE);
            return;
        }
        elapsedTextField.setText(Utils.intervalToTime(interval));
    }//GEN-LAST:event_calcElapsedTimeBtn1ActionPerformed

    private void calcAvgSpeedBtnActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_calcAvgSpeedBtnActionPerformed
        double interval = Utils.timetoInterval(elapsedTextField.getText()) / 3600.0;
        if (interval <= 0) {
            JOptionPane.showMessageDialog(this, I18n.getMsg("rideForm.invalidInterval"),
                    I18n.getMsg("mainWindow.title"), JOptionPane.ERROR_MESSAGE);
            return;
        }
        double distance;
        try {
            distance = Units.toStdSDist(NumberFormat.
                    getInstance().parse(distanceTextField.getText()).doubleValue());
        } catch (Exception e) {
            JOptionPane.showMessageDialog(this, I18n.getMsg("rideForm.invalidDistance"),
                    I18n.getMsg("mainWindow.title"), JOptionPane.ERROR_MESSAGE);
            return;
        }
        speedTextField.setText(Utils.doubleToStr(Units.fromStdSpeed(distance / interval)));
    }//GEN-LAST:event_calcAvgSpeedBtnActionPerformed

    private void okBtnActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_okBtnActionPerformed
        try {
            getValues();
        } catch (Exception e) {
            JOptionPane.showMessageDialog(this, e.getMessage(),
                    I18n.getMsg("mainWindow.title"), JOptionPane.ERROR_MESSAGE);
            return;
        }
        okPressed = true;
        setVisible(false);
    }//GEN-LAST:event_okBtnActionPerformed

    private void cancelBtnActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_cancelBtnActionPerformed
        okPressed = false;
        setVisible(false);
    }//GEN-LAST:event_cancelBtnActionPerformed
    
    /** Closes the dialog */
    private void closeDialog(java.awt.event.WindowEvent evt) {//GEN-FIRST:event_closeDialog
        setVisible(false);
    }//GEN-LAST:event_closeDialog
    
    public static SwimmingEvent add(java.awt.Frame owner, Log log, Date start) {
        SwimmingEvent event = new SwimmingEvent();
        event.setStart(start);
        event.setFinish(start);
        SwimmingWindow sw = new SwimmingWindow(owner, log, event, false);
        sw.setVisible(true);
        sw.dispose();
        return sw.okPressed ? event : null;
    }
    
    public static boolean edit(java.awt.Frame owner, SwimmingEvent event, Log log) {
        SwimmingWindow sw = new SwimmingWindow(owner, log, event, true);
        sw.setVisible(true);
        sw.dispose();
        return sw.okPressed;
    }
    
    
    // Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.JLabel avgSpeedLabel;
    private javax.swing.JButton calcAvgSpeedBtn;
    private javax.swing.JButton calcElapsedTimeBtn1;
    private javax.swing.JTextField caloriesTextField;
    private javax.swing.JButton cancelBtn;
    private javax.swing.JLabel distLabel;
    private javax.swing.JTextField distanceTextField;
    private javax.swing.JTextField elapsedTextField;
    private org.rapla.components.calendar.RaplaCalendar finishCalendar;
    private org.rapla.components.calendar.RaplaTime finishTime;
    private javax.swing.JTextField hrTextField;
    private javax.swing.JLabel jLabel12;
    private javax.swing.JLabel jLabel16;
    private javax.swing.JLabel jLabel17;
    private javax.swing.JLabel jLabel18;
    private javax.swing.JLabel jLabel2;
    private javax.swing.JLabel jLabel3;
    private javax.swing.JLabel jLabel4;
    private javax.swing.JLabel jLabel8;
    private javax.swing.JLabel jLabel9;
    private javax.swing.JPanel jPanel1;
    private javax.swing.JPanel jPanel2;
    private javax.swing.JPanel jPanel4;
    private javax.swing.JPanel jPanel6;
    private javax.swing.JPanel jPanel7;
    private javax.swing.JScrollPane jScrollPane1;
    private javax.swing.JTabbedPane jTabbedPane1;
    private javax.swing.JTextArea notesTextArea;
    private javax.swing.JButton okBtn;
    private javax.swing.JTextField speedTextField;
    private org.rapla.components.calendar.RaplaCalendar startCalendar;
    private org.rapla.components.calendar.RaplaTime startTime;
    private javax.swing.JComboBox styleCombo;
    private javax.swing.JLabel weightLabel;
    private javax.swing.JTextField weightTextField;
    // End of variables declaration//GEN-END:variables
    
}
